pub struct GithubAsset {
pub name: String,
pub url: String,
}Fields
name: Stringurl: StringTrait Implementations
Sourceimpl Clone for GithubAsset
impl Clone for GithubAsset
Sourcefn clone(&self) -> GithubAsset
fn clone(&self) -> GithubAsset
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GithubAsset
impl Debug for GithubAsset
Sourceimpl<'de> Deserialize<'de> for GithubAsset
impl<'de> Deserialize<'de> for GithubAsset
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for GithubAsset
impl Display for GithubAsset
Sourceimpl Hash for GithubAsset
impl Hash for GithubAsset
Sourceimpl PartialEq for GithubAsset
impl PartialEq for GithubAsset
Sourceimpl ReleaseAsset for GithubAsset
impl ReleaseAsset for GithubAsset
Sourcefn get_download_url(&self) -> &str
fn get_download_url(&self) -> &str
Gets asset download url
Sourcefn download(
&self,
additional_headers: Vec<(&str, &str)>,
download_callback: Option<impl Fn(f32)>,
) -> Result<(), Error>
fn download( &self, additional_headers: Vec<(&str, &str)>, download_callback: Option<impl Fn(f32)>, ) -> Result<(), Error>
Downloads asset.
This function can be used directly or with the api through which the asset was fetched.
You may want to use it with the api for automatically passing the token Read more
impl Eq for GithubAsset
impl StructuralPartialEq for GithubAsset